summaryrefslogtreecommitdiffstats
path: root/korn/keditlistboxman.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/keditlistboxman.h')
-rw-r--r--korn/keditlistboxman.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/korn/keditlistboxman.h b/korn/keditlistboxman.h
index 6792ee81..ffc2920e 100644
--- a/korn/keditlistboxman.h
+++ b/korn/keditlistboxman.h
@@ -35,24 +35,24 @@ class KEditListBoxManager : public KEditListBox
{ Q_OBJECT
public:
/**
* Constructor: @see KEditListBoxManager::KEditListBoxManager( const QString&, QWidget, const char * name, bool, int )
*/
- KEditListBoxManager( QWidget *parent = 0, const char *name = 0,
+ KEditListBoxManager( TQWidget *parent = 0, const char *name = 0,
bool checkAtEntering=true, int buttons = All );
/**
* The save as above, but with other options for KEditListBox.
*/
- KEditListBoxManager( const QString& title, QWidget *parent = 0,
+ KEditListBoxManager( const TQString& title, TQWidget *parent = 0,
const char *name = 0, bool checkAtEntering=true,
int buttons = All );
/**
* The save as above, but with other options for KEditListBox.
*/
- KEditListBoxManager( const QString& title,
+ KEditListBoxManager( const TQString& title,
const KEditListBox::CustomEditor &customEditor,
- QWidget *parent = 0, const char *name = 0,
+ TQWidget *parent = 0, const char *name = 0,
bool checkAtEntering = true, int buttons = All );
/**
@@ -71,14 +71,14 @@ public:
* It is used for makeing groupnames.
* @param name The groupname
*/
- void setGroupName( const QString& name );
+ void setGroupName( const TQString& name );
/**
* Sets the subGroupName. subGroupName should contain %1 and %2.
* It is used to execute operations on a group and its subgroups.
* @param name The groupname
*/
- void setSubGroupName( const QString& name );
+ void setSubGroupName( const TQString& name );
private:
/**
* This functions is called from and only from the constructor to prevent writing the
@@ -92,17 +92,17 @@ private:
void readNames();
private:
KConfig *_config; //Stores the KConfig-object
- QString *_groupName; //Stores the groupName string.
- QString *_subGroupName;
+ TQString *_groupName; //Stores the groupName string.
+ TQString *_subGroupName;
int _prevCount;
private slots:
//These comes directly from the KEditListBox itselfs.
void slotChanged();
- void slotAdded( const QString& );
- void slotRemoved( const QString& );
+ void slotAdded( const TQString& );
+ void slotRemoved( const TQString& );
- void slotActivated( QListBoxItem* );
+ void slotActivated( TQListBoxItem* );
private:
/**
* This private method moves an item. It is called from slotChanged().
@@ -128,7 +128,7 @@ signals:
* This signal is emitted when somebody selects an item
* @param text The text of the newly selected item.
*/
- void activated( const QString& text );
+ void activated( const TQString& text );
/**
* This signal is emitted when defaults have to be set.
@@ -137,7 +137,7 @@ signals:
* @param index The number of the item.
* this config is already in the right group.
*/
- void setDefaults( const QString& name, const int index, KConfig* config );
+ void setDefaults( const TQString& name, const int index, KConfig* config );
void elementsSwapped( int, int );
void elementDeleted( int );
@@ -35,24 +35,24 @@ class KEditListBoxManager : public KEditListBox
public:
/**
- * Constructor: @see KEditListBoxManager::KEditListBoxManager( const QString&, QWidget, const char * name, bool, int )
+ * Constructor: @see KEditListBoxManager::KEditListBoxManager( const TQString&, TQWidget, const char * name, bool, int )
*/